## Hyjinx

Some [Hy](http://hylang.org) convenience things.

### Optional dependencies

Optionally, you can install with the `[zmq]` option which also installs [pyzmq](https://pypi.org/project/pyzmq/) and [zstandard](https://pypi.org/project/zstandard/) for the zmq server/client
